summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authoralex <alex@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-05-21 04:11:36 +0000
committeralex <alex@ae88bc3d-4319-0410-8dbf-d08b4c9d3795>1999-05-21 04:11:36 +0000
commit91a39c8938c26fe7b5b2b785cbdead0bb62f6ca7 (patch)
tree4dd1e51a93ee0a45fed5454b1b42992b0214ae58
parentd54dc30bc827e300cc0c97478b7477b4a932a93c (diff)
downloadATCD-91a39c8938c26fe7b5b2b785cbdead0bb62f6ca7.tar.gz
Removed IIOP from the names of RMS and ReplyDispatcher classes.
-rw-r--r--TAO/tao/Reply_Dispatcher.cpp18
-rw-r--r--TAO/tao/Reply_Dispatcher.h16
-rw-r--r--TAO/tao/Request_Mux_Strategy.cpp46
-rw-r--r--TAO/tao/Request_Mux_Strategy.h44
-rw-r--r--TAO/tao/Wait_Strategy.cpp15
-rw-r--r--TAO/tao/Wait_Strategy.h16
6 files changed, 76 insertions, 79 deletions
diff --git a/TAO/tao/Reply_Dispatcher.cpp b/TAO/tao/Reply_Dispatcher.cpp
index 651963ce614..5a6557ab1f4 100644
--- a/TAO/tao/Reply_Dispatcher.cpp
+++ b/TAO/tao/Reply_Dispatcher.cpp
@@ -1,54 +1,54 @@
// $Id$
-#include "tao/IIOP_Reply_Dispatcher.h"
+#include "tao/Reply_Dispatcher.h"
// Constructor.
-TAO_IIOP_Reply_Dispatcher::TAO_IIOP_Reply_Dispatcher (void)
+TAO_Reply_Dispatcher::TAO_Reply_Dispatcher (void)
: request_id_ (0),
cdr_ (0)
{
}
// Destructor.
-TAO_IIOP_Reply_Dispatcher::~TAO_IIOP_Reply_Dispatcher (void)
+TAO_Reply_Dispatcher::~TAO_Reply_Dispatcher (void)
{
}
void
-TAO_IIOP_Reply_Dispatcher::request_id (CORBA::ULong request_id)
+TAO_Reply_Dispatcher::request_id (CORBA::ULong request_id)
{
this->request_id_ = request_id;
}
CORBA::ULong
-TAO_IIOP_Reply_Dispatcher::request_id (void) const
+TAO_Reply_Dispatcher::request_id (void) const
{
return this->request_id_;
}
void
-TAO_IIOP_Reply_Dispatcher::reply_status (CORBA::ULong reply_status)
+TAO_Reply_Dispatcher::reply_status (CORBA::ULong reply_status)
{
this->reply_status_ = reply_status;
}
// Get the reply status.
CORBA::ULong
-TAO_IIOP_Reply_Dispatcher::reply_status (void) const
+TAO_Reply_Dispatcher::reply_status (void) const
{
return this->reply_status_;
}
// Set the CDR which the has the reply message.
void
-TAO_IIOP_Reply_Dispatcher::cdr (TAO_InputCDR *cdr)
+TAO_Reply_Dispatcher::cdr (TAO_InputCDR *cdr)
{
this->cdr_ = cdr;
}
// Get the CDR stream.
TAO_InputCDR *
-TAO_IIOP_Reply_Dispatcher::cdr (void) const
+TAO_Reply_Dispatcher::cdr (void) const
{
return this->cdr_;
}
diff --git a/TAO/tao/Reply_Dispatcher.h b/TAO/tao/Reply_Dispatcher.h
index c8ba37ae426..01d3c9b3138 100644
--- a/TAO/tao/Reply_Dispatcher.h
+++ b/TAO/tao/Reply_Dispatcher.h
@@ -6,7 +6,7 @@
// TAO
//
// = FILENAME
-// IIOP_Reply_Dispatcher.h
+// Reply_Dispatcher.h
//
// = DESCRIPTION
// Dispatch the reply appropriately.
@@ -16,8 +16,8 @@
//
// ============================================================================
-#ifndef TAO_IIOP_REPLY_DISPATCHER_H
-#define TAO_IIOP_REPLY_DISPATCHER_H
+#ifndef TAO_REPLY_DISPATCHER_H
+#define TAO_REPLY_DISPATCHER_H
#include "tao/GIOP.h"
@@ -26,7 +26,7 @@
class TAO_Stub;
class TAO_InputCDR;
-class TAO_Export TAO_IIOP_Reply_Dispatcher
+class TAO_Export TAO_Reply_Dispatcher
{
// = TITLE
//
@@ -34,10 +34,10 @@ class TAO_Export TAO_IIOP_Reply_Dispatcher
//
public:
- TAO_IIOP_Reply_Dispatcher (void);
+ TAO_Reply_Dispatcher (void);
// Constructor.
- virtual ~TAO_IIOP_Reply_Dispatcher (void);
+ virtual ~TAO_Reply_Dispatcher (void);
// Destructor.
void request_id (CORBA::ULong request_id);
@@ -74,7 +74,7 @@ protected:
// Replt status.
};
-class TAO_Export TAO_Synch_Reply_Dispatcher : public TAO_IIOP_Reply_Dispatcher
+class TAO_Export TAO_Synch_Reply_Dispatcher : public TAO_Reply_Dispatcher
{
// = TITLE
//
@@ -94,4 +94,4 @@ public:
// NO OP.
};
-#endif /* TAO_IIOP_REPLY_DISPATCHER_H */
+#endif /* TAO_REPLY_DISPATCHER_H */
diff --git a/TAO/tao/Request_Mux_Strategy.cpp b/TAO/tao/Request_Mux_Strategy.cpp
index 4e42cd5df01..52a00fe8877 100644
--- a/TAO/tao/Request_Mux_Strategy.cpp
+++ b/TAO/tao/Request_Mux_Strategy.cpp
@@ -1,6 +1,6 @@
// $Id$
-#include "tao/IIOP_RMS.h"
+#include "tao/Request_Mux_Strategy.h"
// @@ Alex: there is another aspect that is controlled by this
// strategy: the demuxed version must idle() the transport
@@ -10,28 +10,28 @@
// to guarantee that nobody else is using it.
// We may need to add a couple of methods to implement that.
-TAO_IIOP_Request_Multiplexing_Strategy::TAO_IIOP_Request_Multiplexing_Strategy (void)
+TAO_Request_Mux_Strategy::TAO_Request_Mux_Strategy (void)
: cdr_ (0)
{
}
-TAO_IIOP_Request_Multiplexing_Strategy::~TAO_IIOP_Request_Multiplexing_Strategy (void)
+TAO_Request_Mux_Strategy::~TAO_Request_Mux_Strategy (void)
{
}
TAO_InputCDR *
-TAO_IIOP_Request_Multiplexing_Strategy::get_cdr_stream (void)
+TAO_Request_Mux_Strategy::get_cdr_stream (void)
{
return cdr_;
}
// *********************************************************************
-TAO_IIOP_Muxed_RMS::TAO_IIOP_Muxed_RMS (void)
+TAO_Muxed_RMS::TAO_Muxed_RMS (void)
{
}
-TAO_IIOP_Muxed_RMS::~TAO_IIOP_Muxed_RMS (void)
+TAO_Muxed_RMS::~TAO_Muxed_RMS (void)
{
// @@ delete ???
}
@@ -39,7 +39,7 @@ TAO_IIOP_Muxed_RMS::~TAO_IIOP_Muxed_RMS (void)
// Generate and return an unique request id for the current
// invocation.
CORBA::ULong
-TAO_IIOP_Muxed_RMS::request_id (void)
+TAO_Muxed_RMS::request_id (void)
{
// @@
return 0;
@@ -47,30 +47,30 @@ TAO_IIOP_Muxed_RMS::request_id (void)
// Bind the dispatcher with the request id.
int
-TAO_IIOP_Muxed_RMS::bind_dispatcher (CORBA::ULong request_id,
- TAO_IIOP_Reply_Dispatcher *rh)
+TAO_Muxed_RMS::bind_dispatcher (CORBA::ULong request_id,
+ TAO_Reply_Dispatcher *rh)
{
// @@
return 0;
}
// Find the Reply Dispatcher.
-TAO_IIOP_Reply_Dispatcher*
-TAO_IIOP_Muxed_RMS::find_dispatcher (CORBA::ULong request_id)
+TAO_Reply_Dispatcher*
+TAO_Muxed_RMS::find_dispatcher (CORBA::ULong request_id)
{
// @@
return 0;
}
void
-TAO_IIOP_Muxed_RMS::set_cdr_stream (TAO_InputCDR *Cdr)
+TAO_Muxed_RMS::set_cdr_stream (TAO_InputCDR *Cdr)
{
// @@
}
void
-TAO_IIOP_Muxed_RMS::destroy_cdr_stream (void)
+TAO_Muxed_RMS::destroy_cdr_stream (void)
{
// @@ Implement.
// delete cdr;
@@ -79,13 +79,13 @@ TAO_IIOP_Muxed_RMS::destroy_cdr_stream (void)
// *********************************************************************
-TAO_IIOP_Exclusive_RMS::TAO_IIOP_Exclusive_RMS (void)
+TAO_Exclusive_RMS::TAO_Exclusive_RMS (void)
: request_id_ (931232), // @@ Hardcoding.
rd_ (0)
{
}
-TAO_IIOP_Exclusive_RMS::~TAO_IIOP_Exclusive_RMS (void)
+TAO_Exclusive_RMS::~TAO_Exclusive_RMS (void)
{
}
@@ -93,15 +93,15 @@ TAO_IIOP_Exclusive_RMS::~TAO_IIOP_Exclusive_RMS (void)
// invocation. We can actually return a predecided ULong, since we
// allow only one invocation over this connection at a time.
CORBA::ULong
-TAO_IIOP_Exclusive_RMS::request_id (void)
+TAO_Exclusive_RMS::request_id (void)
{
return this->request_id_;
}
// Bind the handler with the request id.
int
-TAO_IIOP_Exclusive_RMS::bind_dispatcher (CORBA::ULong request_id,
- TAO_IIOP_Reply_Dispatcher *rd)
+TAO_Exclusive_RMS::bind_dispatcher (CORBA::ULong request_id,
+ TAO_Reply_Dispatcher *rd)
{
this->request_id_ = request_id;
this->rd_ = rd;
@@ -109,12 +109,12 @@ TAO_IIOP_Exclusive_RMS::bind_dispatcher (CORBA::ULong request_id,
}
// Find the Reply Handler.
-TAO_IIOP_Reply_Dispatcher *
-TAO_IIOP_Exclusive_RMS::find_dispatcher (CORBA::ULong request_id)
+TAO_Reply_Dispatcher *
+TAO_Exclusive_RMS::find_dispatcher (CORBA::ULong request_id)
{
if (this->request_id_ != request_id)
ACE_ERROR_RETURN ((LM_ERROR,
- "%N:%l:TAO_IIOP_Exclusive_RMS::find_handler: ",
+ "%N:%l:TAO_Exclusive_RMS::find_handler: ",
"Failed to find the handler\n"),
0);
@@ -124,13 +124,13 @@ TAO_IIOP_Exclusive_RMS::find_dispatcher (CORBA::ULong request_id)
// Set the CDR stream.
void
-TAO_IIOP_Exclusive_RMS::set_cdr_stream (TAO_InputCDR *cdr)
+TAO_Exclusive_RMS::set_cdr_stream (TAO_InputCDR *cdr)
{
this->cdr_ = cdr;
}
// NOOP function.
void
-TAO_IIOP_Exclusive_RMS::destroy_cdr_stream (void)
+TAO_Exclusive_RMS::destroy_cdr_stream (void)
{
}
diff --git a/TAO/tao/Wait_Strategy.cpp b/TAO/tao/Wait_Strategy.cpp
index 692c59455df..b3a37c87cbb 100644
--- a/TAO/tao/Wait_Strategy.cpp
+++ b/TAO/tao/Wait_Strategy.cpp
@@ -1,20 +1,17 @@
// $Id$
-#include "tao/IIOP_Wait_Strategy.h"
+#include "tao/Wait_Strategy.h"
#include "tao/Pluggable.h"
#include "tao/ORB_Core.h"
-// @@ This is not IIOP specific, ditto for IIOP_RMS and
-// IIOP_Reply_Dispatcher
-
// Constructor.
-TAO_IIOP_Wait_Strategy::TAO_IIOP_Wait_Strategy (TAO_Transport *transport)
+TAO_Wait_Strategy::TAO_Wait_Strategy (TAO_Transport *transport)
: transport_ (transport)
{
}
// Destructor.
-TAO_IIOP_Wait_Strategy::~TAO_IIOP_Wait_Strategy (void)
+TAO_Wait_Strategy::~TAO_Wait_Strategy (void)
{
}
@@ -22,7 +19,7 @@ TAO_IIOP_Wait_Strategy::~TAO_IIOP_Wait_Strategy (void)
// Constructor.
TAO_Wait_On_Reactor::TAO_Wait_On_Reactor (TAO_Transport *transport)
- : TAO_IIOP_Wait_Strategy (transport)
+ : TAO_Wait_Strategy (transport)
{
}
@@ -61,7 +58,7 @@ TAO_Wait_On_Reactor::wait (void)
// Constructor.
TAO_Wait_On_Leader_Follower::TAO_Wait_On_Leader_Follower (TAO_Transport *transport)
- : TAO_IIOP_Wait_Strategy (transport)
+ : TAO_Wait_Strategy (transport)
{
}
@@ -124,7 +121,7 @@ TAO_Wait_On_Leader_Follower::wait (void)
// Constructor.
TAO_Wait_On_Read::TAO_Wait_On_Read (TAO_Transport *transport)
- : TAO_IIOP_Wait_Strategy (transport)
+ : TAO_Wait_Strategy (transport)
{
}
diff --git a/TAO/tao/Wait_Strategy.h b/TAO/tao/Wait_Strategy.h
index aeb863951d7..254f38999a2 100644
--- a/TAO/tao/Wait_Strategy.h
+++ b/TAO/tao/Wait_Strategy.h
@@ -6,7 +6,7 @@
// TAO
//
// = FILENAME
-// IIOP_Wait_Strategy.h
+// Wait_Strategy.h
//
// = DESCRIPTION
// Classes to strategize waiting for reply.
@@ -19,10 +19,10 @@
#include "tao/GIOP.h"
-class TAO_IIOP_Request_Multiplexing_Strategy;
+class TAO_Request_Mux_Strategy;
class TAO_Transport;
-class TAO_Export TAO_IIOP_Wait_Strategy
+class TAO_Export TAO_Wait_Strategy
{
// = TITLE
//
@@ -32,10 +32,10 @@ class TAO_Export TAO_IIOP_Wait_Strategy
//
public:
- TAO_IIOP_Wait_Strategy (TAO_Transport *transport);
+ TAO_Wait_Strategy (TAO_Transport *transport);
// Constructor.
- virtual ~TAO_IIOP_Wait_Strategy (void);
+ virtual ~TAO_Wait_Strategy (void);
// Destructor.
virtual int wait (void) = 0;
@@ -46,7 +46,7 @@ protected:
// Transport object.
};
-class TAO_Export TAO_Wait_On_Reactor : public TAO_IIOP_Wait_Strategy
+class TAO_Export TAO_Wait_On_Reactor : public TAO_Wait_Strategy
{
// = TITLE
//
@@ -67,7 +67,7 @@ public:
// Do the event loop of the Reactor.
};
-class TAO_Export TAO_Wait_On_Leader_Follower : public TAO_IIOP_Wait_Strategy
+class TAO_Export TAO_Wait_On_Leader_Follower : public TAO_Wait_Strategy
{
// = TITLE
//
@@ -89,7 +89,7 @@ public:
// Wait according to the L-F model.
};
-class TAO_Export TAO_Wait_On_Read : public TAO_IIOP_Wait_Strategy
+class TAO_Export TAO_Wait_On_Read : public TAO_Wait_Strategy
{
// = TITLE
//
diff --git a/TAO/tao/Request_Mux_Strategy.h b/TAO/tao/Request_Mux_Strategy.h
index 11ae6f3ceb8..3a382cd191f 100644
--- a/TAO/tao/Request_Mux_Strategy.h
+++ b/TAO/tao/Request_Mux_Strategy.h
@@ -6,27 +6,27 @@
// TAO
//
// = FILENAME
-// IIOP_RMS.h
+// Request_Mux_Strategy.h
//
// = DESCRIPTION
// IIOP Request Multiplexing Strategies.
//
// = AUTHOR
// Alexander Babu Arulanthu <alex@cs.wustl.edu>
//
// ============================================================================
-#ifndef TAO_IIOP_RMS_H
-#define TAO_IIOP_RMS_H
+#ifndef TAO_REQUEST_MUX_STRATEGY_H
+#define TAO_REQUEST_MUX_STRATEGY_H
#include "tao/CDR.h"
// Forward declarations.
-class TAO_IIOP_Reply_Dispatcher;
+class TAO_Reply_Dispatcher;
-class TAO_Export TAO_IIOP_Request_Multiplexing_Strategy
+class TAO_Export TAO_Request_Mux_Strategy
{
// = TITLE
//
@@ -38,10 +38,10 @@ class TAO_Export TAO_IIOP_Request_Multiplexing_Strategy
//
public:
- TAO_IIOP_Request_Multiplexing_Strategy (void);
+ TAO_Request_Mux_Strategy (void);
// Base class constructor.
- virtual ~TAO_IIOP_Request_Multiplexing_Strategy (void);
+ virtual ~TAO_Request_Mux_Strategy (void);
// Base class destructor.
virtual CORBA::ULong request_id (void) = 0;
@@ -53,10 +53,10 @@ public:
// the AMI's.
virtual int bind_dispatcher (CORBA::ULong request_id,
- TAO_IIOP_Reply_Dispatcher *rh) = 0;
+ TAO_Reply_Dispatcher *rh) = 0;
// Bind the dispatcher with the request id.
- virtual TAO_IIOP_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id) = 0;
+ virtual TAO_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id) = 0;
// Find the Reply Dispatcher.
// = "Factory methods" to obtain the CDR stream, in the Muxed case
@@ -79,7 +79,7 @@ protected:
// the SMI and dynamically allocated in AMI.
};
-class TAO_Export TAO_IIOP_Muxed_RMS : public TAO_IIOP_Request_Multiplexing_Strategy
+class TAO_Export TAO_Muxed_RMS : public TAO_Request_Mux_Strategy
{
// = TITLE
//
@@ -89,10 +89,10 @@ class TAO_Export TAO_IIOP_Muxed_RMS : public TAO_IIOP_Request_Multiplexing_Stra
//
public:
- TAO_IIOP_Muxed_RMS (void);
+ TAO_Muxed_RMS (void);
// Constructor.
- virtual ~TAO_IIOP_Muxed_RMS (void);
+ virtual ~TAO_Muxed_RMS (void);
// Destructor.
virtual CORBA::ULong request_id (void);
@@ -100,10 +100,10 @@ public:
// invocation.
virtual int bind_dispatcher (CORBA::ULong request_id,
- TAO_IIOP_Reply_Dispatcher *rh);
+ TAO_Reply_Dispatcher *rh);
// Bind the dispatcher with the request id.
- virtual TAO_IIOP_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id);
+ virtual TAO_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id);
// Find the Reply Dispatcher.
// virtual TAO_InputCDR *cdr_stream (void);
@@ -122,7 +122,7 @@ protected:
// @@ HASH TABLE???
};
-class TAO_Export TAO_IIOP_Exclusive_RMS : public TAO_IIOP_Request_Multiplexing_Strategy
+class TAO_Export TAO_Exclusive_RMS : public TAO_Request_Mux_Strategy
{
// = TITLE
//
@@ -132,10 +132,10 @@ class TAO_Export TAO_IIOP_Exclusive_RMS : public TAO_IIOP_Request_Multiplexing_S
//
public:
- TAO_IIOP_Exclusive_RMS (void);
+ TAO_Exclusive_RMS (void);
// Constructor.
- virtual ~TAO_IIOP_Exclusive_RMS (void);
+ virtual ~TAO_Exclusive_RMS (void);
// Destructor.
virtual CORBA::ULong request_id (void);
@@ -144,10 +144,10 @@ public:
// allow only one invocation over this connection at a time.
virtual int bind_dispatcher (CORBA::ULong request_id,
- TAO_IIOP_Reply_Dispatcher *rh);
+ TAO_Reply_Dispatcher *rh);
// Bind the dispatcher with the request id.
- virtual TAO_IIOP_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id);
+ virtual TAO_Reply_Dispatcher* find_dispatcher (CORBA::ULong request_id);
// Find the Reply Dispatcher.
// virtual TAO_InputCDR *get_cdr_stream (void);
@@ -166,7 +166,7 @@ protected:
CORBA::ULong request_id_;
// Request id for the current request.
- TAO_IIOP_Reply_Dispatcher *rd_;
+ TAO_Reply_Dispatcher *rd_;
// Reply Dispatcher corresponding to the request.
};
-#endif /* IIOP_RMS_H */
+#endif /* REQUEST_MUX_STRATEGY_H */
@@ -6,27 +6,27 @@
//
// = DESCRIPTION
-// IIOP Request Multiplexing Strategies.
+// IIOP Request Mux Strategies.
//
// = AUTHOR